{% load i18n %}
{% load crispy_forms_tags %}
<form action="" method="post" enctype="multipart/form-data" onsubmit="newbtnDisabled()">
    <input type="hidden" name="csrfmiddlewaretoken" id="token2">
    <div class="modal-body mid-modal-scroll modal1">
        {{form.media}}
        {{form|crispy}}
        <h3 class="fs-5 oxanium text-center">{% trans "Applied Science" %}</h3>
        <div id="new-formset">
            {{ formset.management_form }}
                {% for form in formset %}
                <div id="form-0" class="new-formset pt-2">
                    {{form|crispy}}
                    {{form|as_crispy_errors}}
                </div>
                {% endfor %}
            <div id="new-empty-form" class="d-none">
                {{formset.empty_form.media}}
                {{formset.empty_form|crispy}}
            </div>
        </div>
        <p class="response-footer text-link fw-bold oxanium"></p>
        <input type="hidden" name="form-id" value="Update2">
        <div class="row justify-content-end p-3">
            <div class="col-lg-4">
                <button type="submit" id="btn-footer" name="btn-footer" class="btn btn-shappire center-btn btn-block new-btn-form d-flex">{% trans "Send" %} <i class="fa-solid fa-paper-plane mx-2"></i></button>      
            </div>
        </div>
    </div>    
</form>