{% load i18n %}
<h1 class="oxanium fs-4">{% trans "You request to remove the following asset" %}</h1>
<ul class="list-style">
  <li>{{page.name}}</li>
</ul>
<p class="text-dark">{% trans "You are about to delete this page and all associated records. Please confirm if you want to proceed with the removal" %}.</p>
<p class="text-dark">{% trans "If you have any questions or need more information, please contact our support team" %}.</p>
<div class="d-flex justify-content-end">
  <button class="btn btn-shappire remove-btn center-btn" onclick="removePage({{page.asset_id}})">{% trans "Continue" %}</button>
</div>  
 