# Generated by Django 4.2.1 on 2023-12-12 01:14

import datetime
from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('stela_control', '0007_remove_booking_user_booking_address_booking_created_and_more'),
    ]

    operations = [
        migrations.AlterField(
            model_name='billingrecipt',
            name='option',
            field=models.CharField(choices=[('budget_development', 'Budget Development'), ('budget_marketing', 'Budget Marketing'), ('Others', 'Others'), ('budget_design', 'Budget Design'), ('Billing receipt', 'Billing receipt'), ('Monthly charge', 'Monthly charge')], max_length=60, null=True, verbose_name='Case'),
        ),
        migrations.AlterField(
            model_name='category',
            name='type',
            field=models.CharField(choices=[('woman', 'woman'), ('male', 'male'), ('curvy', 'curvy'), ('kids', 'kids'), ('furniture', 'furniture'), ('Select Type', 'Select Type'), ('Consulting', 'Consulting')], default='Select Type', max_length=30, verbose_name='Type'),
        ),
        migrations.AlterField(
            model_name='company',
            name='business',
            field=models.CharField(blank=True, choices=[('E-commerce', 'E-commerce'), ('IT Development Services', 'IT Development Services'), ('Media Creators', 'Media Creators'), ('Logistics and Transportation Services', 'Logistics and Transportation Services'), ('Marketing and Advertising Services', 'Marketing and Advertising Services'), ('Education and Training', 'Education and Training'), ('Repair and Maintenance Services', 'Repair and Maintenance Services'), ('Restaurants and Food Services', 'Restaurants and Food Services'), ('Consulting', 'Consulting'), ('Health and Wellness', 'Health and Wellness'), ('Beauty and Personal Care Services', 'Beauty and Personal Care Services')], max_length=100, null=True, verbose_name='Business Type'),
        ),
        migrations.AlterField(
            model_name='content',
            name='card',
            field=models.CharField(blank=True, choices=[('card-tale', 'card-tale'), ('card-light-blue', 'card-light-blue'), ('card-dark-blue', 'card-dark-blue'), ('card-light-danger', 'card-light-danger')], max_length=50, null=True, verbose_name='Color Card'),
        ),
        migrations.AlterField(
            model_name='content',
            name='category',
            field=models.CharField(blank=True, choices=[('Inspiration', 'Inspiration'), ('Events and Conferences', 'Events and Conferences'), ('Tips and Tricks', 'Tips and Tricks'), ('Interviews', 'Interviews'), ('Guides and Manuals', 'Guides and Manuals'), ('Tutorials', 'Tutorials'), ('News', 'News')], default='News', max_length=100),
        ),
        migrations.AlterField(
            model_name='facebookpagecomments',
            name='update_rate',
            field=models.DateTimeField(default=datetime.datetime(2023, 12, 11, 22, 13, 43, 707438)),
        ),
        migrations.AlterField(
            model_name='itemdiscount',
            name='field',
            field=models.CharField(choices=[('Stela Payment Free Suscription', 'Stela Payment Free Suscription'), ('No Selected', 'No Selected'), ('Initial Payment', 'Initial Payment'), ('Promotional Discount', 'Promotional Discount')], max_length=60),
        ),
        migrations.AlterField(
            model_name='newsletter',
            name='status',
            field=models.CharField(choices=[('Send', 'Send'), ('Draft', 'Draft')], max_length=20),
        ),
        migrations.AlterField(
            model_name='newsletter',
            name='template',
            field=models.CharField(choices=[('Style Template 4', 'Style Template 4'), ('Style Template 1', 'Style Template 1'), ('Style Template 2', 'Style Template 2'), ('Style Template 3', 'Style Template 3')], max_length=60, null=True, verbose_name='Style'),
        ),
        migrations.AlterField(
            model_name='order',
            name='section',
            field=models.CharField(choices=[('Cloud Elastic Instance', 'Cloud Elastic Instance'), ('Store', 'Store'), ('Stela Websites', 'Stela Websites'), ('No Selected', 'No Selected'), ('Cloud Domains', 'Cloud Domains'), ('Stela Marketing', 'Stela Marketing'), ('Stela Design', 'Stela Design')], default='No Selected', max_length=50),
        ),
        migrations.AlterField(
            model_name='pathcontrol',
            name='step',
            field=models.CharField(choices=[('Step 4', 'Step 4'), ('Step 3', 'Step 3'), ('Step 2', 'Step 2')], default='No Selected', max_length=50),
        ),
        migrations.AlterField(
            model_name='sitepolicy',
            name='section',
            field=models.CharField(blank=True, choices=[('Privacy Policy', 'Privacy Policy'), ('Return Policy', 'Return Policy'), ('budget_marketing_terms', 'Budget Marketing Terms'), ('Terms and Conditions', 'Terms and Conditions'), ('budget_design_terms', 'Budget Design Terms'), ('budget_development_terms', 'Budget Development Terms'), ('Disclaimer', 'Disclaimer'), ('Cookie Policy', 'Cookie Policy'), ('billing_terms', 'Monthly Billing Terms'), ('monthly_terms', 'Billing Terms')], default='Terms and Conditions', max_length=150),
        ),
        migrations.AlterField(
            model_name='sociallinks',
            name='social',
            field=models.CharField(choices=[('Github', 'Github'), ('Tiktok', 'Tiktok'), ('Instagram', 'Instagram'), ('Linkedin', 'Linkedin'), ('Facebook', 'Facebook'), ('X', 'X'), ('Youtube', 'Youtube')], default='No Selected', max_length=50),
        ),
        migrations.AlterField(
            model_name='support',
            name='option',
            field=models.CharField(choices=[('I have a problem with my subscription', 'I have a problem with my subscription'), ('My delivery has been delayed', 'My delivery has been delayed'), ('Others', 'Others'), ('I have a problem with my project', 'I have a problem with my project'), ('My account has an error', 'My account has an error'), ('Payments Issue', 'Payments Issue')], max_length=60, verbose_name='Case'),
        ),
        migrations.AlterField(
            model_name='wallet',
            name='type',
            field=models.CharField(choices=[('Binance', 'Binance'), ('Zelle', 'Zelle'), ('Paypal', 'Paypal')], max_length=100, verbose_name='Type of Wallet'),
        ),
        migrations.CreateModel(
            name='BookingServices',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('service', models.CharField(max_length=250)),
                ('created', models.DateTimeField(auto_now_add=True)),
                ('parent', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='booking_services', to='stela_control.booking')),
            ],
        ),
    ]
