{% load i18n %}
{% load crispy_forms_tags %}       
<div id="formset">
    {{ formset.management_form }}
        {% for form in formset %}
        <div id="form-0" class="formset5 pt-2">
            {{form|crispy}}
            {{form|as_crispy_errors}}
        </div>
        <hr>
        {% endfor %}
    <div id="empty-form5" class="d-none">
        {{formset.empty_form.media}}
        {{formset.empty_form|crispy}}
    </div>
</div>
<div class="d-flex justify-content-between my-3">
    <button class="btn-clear" onclick="addFormset()" type="button"><i class="fa-solid fa-plus"></i>{% trans " Add" %}</button>
    <button class="btn-clear" onclick="clearFormset()" type="button"><i class="fa-solid fa-minus"></i> {% trans "Remove" %}</button>
</div> 
<p class="response-footer text-link fw-bold oxanium"></p>
<input type="hidden" name="form-id" value="colorForm">