# Generated by Django 4.2.1 on 2023-11-20 13:08

import datetime
from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
        ('stela_control', '0003_alter_billingrecipt_option_alter_company_business_and_more'),
    ]

    operations = [
        migrations.AlterField(
            model_name='billingrecipt',
            name='option',
            field=models.CharField(choices=[('budget_design', 'Budget Design'), ('budget_development', 'Budget Development'), ('Monthly charge', 'Monthly charge'), ('Billing receipt', 'Billing receipt'), ('budget_marketing', 'Budget Marketing'), ('Others', 'Others')], max_length=60, null=True, verbose_name='Case'),
        ),
        migrations.AlterField(
            model_name='company',
            name='business',
            field=models.CharField(blank=True, choices=[('Restaurants and Food Services', 'Restaurants and Food Services'), ('Marketing and Advertising Services', 'Marketing and Advertising Services'), ('Media Creators', 'Media Creators'), ('Beauty and Personal Care Services', 'Beauty and Personal Care Services'), ('Logistics and Transportation Services', 'Logistics and Transportation Services'), ('IT Development Services', 'IT Development Services'), ('E-commerce', 'E-commerce'), ('Repair and Maintenance Services', 'Repair and Maintenance Services'), ('Consulting', 'Consulting'), ('Education and Training', 'Education and Training'), ('Health and Wellness', 'Health and Wellness')], max_length=100, null=True, verbose_name='Business Type'),
        ),
        migrations.AlterField(
            model_name='content',
            name='card',
            field=models.CharField(blank=True, choices=[('card-light-danger', 'card-light-danger'), ('card-tale', 'card-tale'), ('card-dark-blue', 'card-dark-blue'), ('card-light-blue', 'card-light-blue')], max_length=50, null=True, verbose_name='Color Card'),
        ),
        migrations.AlterField(
            model_name='content',
            name='category',
            field=models.CharField(blank=True, choices=[('Guides and Manuals', 'Guides and Manuals'), ('Events and Conferences', 'Events and Conferences'), ('Tips and Tricks', 'Tips and Tricks'), ('Inspiration', 'Inspiration'), ('Tutorials', 'Tutorials'), ('News', 'News'), ('Interviews', 'Interviews')], default='News', max_length=100),
        ),
        migrations.AlterField(
            model_name='facebookpagecomments',
            name='update_rate',
            field=models.DateTimeField(default=datetime.datetime(2023, 11, 20, 10, 7, 56, 152635)),
        ),
        migrations.AlterField(
            model_name='itemdiscount',
            name='field',
            field=models.CharField(choices=[('Promotional Discount', 'Promotional Discount'), ('Stela Payment Free Suscription', 'Stela Payment Free Suscription'), ('Initial Payment', 'Initial Payment'), ('No Selected', 'No Selected')], max_length=60),
        ),
        migrations.AlterField(
            model_name='newsletter',
            name='status',
            field=models.CharField(choices=[('Draft', 'Draft'), ('Send', 'Send')], max_length=20),
        ),
        migrations.AlterField(
            model_name='newsletter',
            name='template',
            field=models.CharField(choices=[('Style Template 3', 'Style Template 3'), ('Style Template 4', 'Style Template 4'), ('Style Template 2', 'Style Template 2'), ('Style Template 1', 'Style Template 1')], max_length=60, null=True, verbose_name='Style'),
        ),
        migrations.AlterField(
            model_name='order',
            name='section',
            field=models.CharField(choices=[('Store', 'Store'), ('Stela Websites', 'Stela Websites'), ('No Selected', 'No Selected'), ('Stela Design', 'Stela Design'), ('Cloud Domains', 'Cloud Domains'), ('Stela Marketing', 'Stela Marketing'), ('Cloud Elastic Instance', 'Cloud Elastic Instance')], default='No Selected', max_length=50),
        ),
        migrations.AlterField(
            model_name='pathcontrol',
            name='step',
            field=models.CharField(choices=[('Step 4', 'Step 4'), ('Step 3', 'Step 3'), ('Step 2', 'Step 2')], default='No Selected', max_length=50),
        ),
        migrations.AlterField(
            model_name='sitepolicy',
            name='section',
            field=models.CharField(blank=True, choices=[('budget_design_terms', 'Budget Design Terms'), ('Cookie Policy', 'Cookie Policy'), ('Return Policy', 'Return Policy'), ('budget_marketing_terms', 'Budget Marketing Terms'), ('billing_terms', 'Monthly Billing Terms'), ('budget_development_terms', 'Budget Development Terms'), ('Terms and Conditions', 'Terms and Conditions'), ('Privacy Policy', 'Privacy Policy'), ('monthly_terms', 'Billing Terms'), ('Disclaimer', 'Disclaimer')], default='Terms and Conditions', max_length=150),
        ),
        migrations.AlterField(
            model_name='sociallinks',
            name='social',
            field=models.CharField(choices=[('Instagram', 'Instagram'), ('Github', 'Github'), ('X', 'X'), ('Youtube', 'Youtube'), ('Facebook', 'Facebook'), ('Tiktok', 'Tiktok'), ('Linkedin', 'Linkedin')], default='No Selected', max_length=50),
        ),
        migrations.AlterField(
            model_name='support',
            name='option',
            field=models.CharField(choices=[('I have a problem with my project', 'I have a problem with my project'), ('Others', 'Others'), ('I have a problem with my subscription', 'I have a problem with my subscription'), ('Payments Issue', 'Payments Issue'), ('My delivery has been delayed', 'My delivery has been delayed'), ('My account has an error', 'My account has an error')], max_length=60, verbose_name='Case'),
        ),
        migrations.AlterField(
            model_name='wallet',
            name='type',
            field=models.CharField(choices=[('Paypal', 'Paypal'), ('Zelle', 'Zelle'), ('Binance', 'Binance')], max_length=100, verbose_name='Type of Wallet'),
        ),
        migrations.CreateModel(
            name='YouTubeToken',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('access_token', models.CharField(max_length=255)),
                ('refresh_token', models.CharField(max_length=255)),
                ('token_type', models.CharField(max_length=50)),
                ('expires_in', models.DateTimeField()),
                ('scope', models.TextField()),
                ('user', models.OneToOneField(on_delete=django.db.models.deletion.CASCADE, related_name='youtube_token', to=settings.AUTH_USER_MODEL)),
            ],
        ),
        migrations.CreateModel(
            name='LiteraryWork',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('title', models.CharField(max_length=100)),
                ('publication_date', models.DateField()),
                ('genre', models.CharField(max_length=50)),
                ('synopsis', models.TextField()),
                ('author', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='literary_author', to=settings.AUTH_USER_MODEL)),
            ],
        ),
    ]
